/**
* Enumeration contains a set of critical remarks detected during analysis of data structure used during SDK work.
* @enum {number}
*/
export declare enum eLDSParsingErrorCodes {
    /**
    * No remarks.
    */
    OK = 1,
    /**
    * Provided ASN.1-data are incorrect (common case – impossible to form elementary ASN.1-objects).
    */
    ASN_INCORRECT_DATA = 2147483649,
    /**
    * Provided ASN.1-data are incorrect (not enough data).
    */
    ASN_NOT_ENOUGH_DATA = 2147483650,
    /**
    * Other contents expected for complex ASN.1-object components by the structure, number of elements.
    */
    ASN_CONTENTS_UNEXPECTED_DATA = 2147483651,
    /**
    * Incorrect format of ASN.1-object SignedData, which is the content of the document security object – common case.
    */
    ASN_SIGNED_DATA_INCORRECT_DATA = 2147483656,
    /**
    * Incorrect format of encapsulated data of encapContentInfo ASN.1-object SignedData, which is the content of the
    * document security object.
    */
    ASN_SIGNED_DATA_ENCAP_CONTENTS_INCORRECT_DATA = 2147483657,
    /**
    * Invalid version field format of SignedData ASN.1-object SignedData , which is the content of the document security
    * object.
    */
    ASN_SIGNED_DATA_VERSION_INCORRECT_DATA = 2147483658,
    /**
    * Invalid format of digestAlgorithms field of SignedData ASN.1-object, which is the content of the document security
    * object.
    */
    ASN_SIGNED_DATA_DIGEST_ALGORITHMS_INCORRECT_DATA = 2147483665,
    /**
    * Incorrect format of LDSSecurityObject ASN.1-object, encapsulated in EF.SOD document security object.
    */
    ASN_LDS_OBJECT_INCORRECT_DATA = 2147483667,
    /**
    * Incorrect format of version field of LDSSecurityObject ASN.1-object, encapsulated in EF.SOD document security
    * object.
    */
    ASN_LDS_OBJECT_VERSION_INCORRECT_DATA = 2147483668,
    /**
    * Incorrect format of hashAlgorithm field of LDSSecurityObject ASN.1-object, encapsulated in EF.SOD document security
    * object.
    */
    ASN_LDS_OBJECT_DIGEST_ALGORITHM_INCORRECT_DATA = 2147483669,
    /**
    * Incorrect format of dataGroupHashes field of LDSSecurityObject ASN.1-object, encapsulated in EF.SOD document
    * security object.
    */
    ASN_LDS_OBJECT_DG_HASHES_INCORRECT_DATA = 2147483670,
    /**
    * Incorrect format of ldsVersionInfo field of LDSSecurityObject ASN.1-object, encapsulated in EF.SOD document
    * security object (for LDS version 1.8).
    */
    ASN_LDS_OBJECT_VERSION_INFO_INCORRECT_DATA = 2147483666,
    /**
    * Incorrect format of Certificate ASN.1-object.
    */
    ASN_CERTIFICATE_INCORRECT_DATA = 2147483671,
    /**
    * Incorrect format of version field of TBSCertificate ASN.1-object.
    */
    ASN_CERTIFICATE_VERSION_INCORRECT_DATA = 2147483672,
    /**
    * Incorrect format of serialNumber field of TBSCertificate ASN.1-object.
    */
    ASN_CERTIFICATE_SN_INCORRECT_DATA = 2147483673,
    /**
    * Incorrect format of signature field of TBSCertificate ASN.1-object.
    */
    ASN_CERTIFICATE_SIGNATURE_INCORRECT_DATA = 2147483674,
    /**
    * Incorrect format of issuer field of TBSCertificate ASN.1-object.
    */
    ASN_CERTIFICATE_ISSUER_INCORRECT_DATA = 2147483675,
    /**
    * Incorrect format of validity field of TBSCertificate ASN.1-object.
    */
    ASN_CERTIFICATE_VALIDITY_INCORRECT_DATA = 2147483676,
    /**
    * Incorrect format of subject field of TBSCertificate ASN.1-object.
    */
    ASN_CERTIFICATE_SUBJECT_INCORRECT_DATA = 2147483677,
    /**
    * Incorrect format of subjectPublicKeyInfo field of TBSCertificate ASN.1-object.
    */
    ASN_CERTIFICATE_SUBJECT_PK_INCORRECT_DATA = 2147483678,
    /**
    * Incorrect format of extensions field of TBSCertificate ASN.1-object.
    */
    ASN_CERTIFICATE_EXTENSIONS_INCORRECT_DATA = 2147483679,
    /**
    * Incorrect format of signerInfos field of SignedData ASN.1-object, which is the
    * contents of the document security object.
    */
    ASN_SIGNER_INFO_INCORRECT_DATA = 2147483680,
    /**
    * Incorrect format of version field of SignedInfo ASN.1-object, containing data
    * of digital signature of the document security object.
    */
    ASN_SIGNER_INFO_VERSION_INCORRECT_DATA = 2147483681,
    /**
    * Incorrect format of sid field of SignedInfo ASN.1-object, containing data of
    * digital signature of the document security object.
    */
    ASN_SIGNER_INFO_SID_INCORRECT_DATA = 2147483682,
    /**
    * Incorrect format of digestAlgorithm field of SignedInfo ASN.1-object, containing data of digital signature
    * of the document security object.
    */
    ASN_SIGNER_INFO_DIGEST_ALG_INCORRECT_DATA = 2147483683,
    /**
    * Incorrect format of signedAttrs field of SignedInfo ASN.1-object, containing
    * data of digital signature of the document security object.
    */
    ASN_SIGNER_INFO_SIGNED_ATTRS_INCORRECT_DATA = 2147483684,
    /**
    * Incorrect format of signatureAlgorithm field of SignedInfo ASN.1-object,
    * containing data of digital signature of the document security object.
    */
    ASN_SIGNER_INFO_SIGN_ALG_INCORRECT_DATA = 2147483685,
    /**
    * Incorrect format of signature field of SignedInfo ASN.1-object, containing data of digital signature
    * of the document security object.
    */
    ASN_SIGNER_INFO_SIGNATURE_INCORRECT_DATA = 2147483686,
    /**
    * Incorrect format of unsignedAttrs field of SignedInfo ASN.1-object, containing data of digital signature
    * of the document security object.
    */
    ASN_SIGNER_INFO_UNSIGNED_ATTRS_INCORRECT_DATA = 2147483687,
    /**
    * hashAlgorithm field of LDSSecurityObject ASN.1-object, encapsulated in EF.SOD
    * document security object, contains identifier (OID) of the unsupported
    * hash algorithm.
    */
    ICAO_LDS_OBJECT_UNSUPPORTED_DIGEST_ALGORITHM = 2147483696,
    /**
    * No digital signature data object was found in the structure of the document security object.
    */
    ICAO_SIGNED_DATA_SIGNER_INFOS_EMPTY = 2147483697,
    /**
    * digestAlgorithm field of SignerInfo ASN.1-object of document security object digital signature contains
    * identifier (OID) of unsupported hash algorithm.
    */
    ICAO_SIGNER_INFO_UNSUPPORTED_DIGEST_ALGORITHM = 2147483698,
    /**
    * signatureAlgorithm field of SignerInfo ASN.1-object of document security object
    * digital signature contains identifier (OID) of unsupported digital signature algorithm.
    */
    ICAO_SIGNER_INFO_UNSUPPORTED_SIGNATURE_ALGORITHM = 2147483699,
    /**
    * Message digest error
    */
    ICAO_SIGNER_INFO_MESSAGE_DIGEST_ERROR = 2147483700,
    /**
    * Mandatory signedAttrs field of SignerInfo ASN.1-object of EF.SOD document security object is not found.
    */
    ICAO_SIGNER_INFO_SIGNED_ATTRS_MISSED = 2147483702,
    /**
    * DS-certificate to verify the digital signature is not found.
    */
    AUTH_SIGNER_INFO_CANT_FIND_CERTIFICATE = 2147483701,
    /**
    * Digital signature verification failed (common case).
    */
    AUTH_ERROR = 2147483728,
    /**
    * Unsupported digital signature algorithm.
    */
    AUTH_UNSUPPORTED_SIGNATURE_ALGORITHM = 2147483729,
    /**
    * Unsupported digital signature public key algorithm.
    */
    AUTH_UNSUPPORTED_PUBLIC_KEY_ALGORITHM = 2147483730,
    /**
    * Digital signature algorithm does not correspond to the public key algorithm.
    */
    AUTH_MESSED_ALGORITHMS = 2147483731,
    /**
    * Incorrect format of the public key data.
    */
    AUTH_PUBLIC_KEY_DATA_INVALID = 2147483732,
    /**
    * Incorrect format of the public key parameters data.
    */
    AUTH_ALGORITHM_PARAMETERS_DATA_INVALID = 2147483733,
    /**
    * Incorrect format of the digital signature data.
    */
    AUTH_SIGNATURE_DATA_INVALID = 2147483734,
    /**
    * Unsupported data hash algorithm for the digital signature verification.
    */
    AUTH_UNSUPPORTED_DIGEST_ALGORITHM = 2147483735,
    /**
    * Incorrect data of the digital signature (by length or compliance with a range of valid values).
    */
    AUTH_SIGNATURE_DATA_INCORRECT = 2147483736,
    /**
    * ECDSA public key parameters are not defined. According to they are defined by
    * EcpkParameters ASN.1-object by one of three possible ways: explicitly, by the named
    * curve identifier, and can also be known a priori. In the case when the parameters are assigned implicity
    * or the specified identifier of the curve is not supported, a procedure of
    * verifying the digital signature becomes impossible.
    */
    AUTH_ALGORITHM_PARAMETERS_NOT_DEFINED = 2147483737,
    /**
    * Digital signature verification failed.
    */
    AUTH_SIGNATURE_CHECK_FAILED = 2147483738,
    /**
    * Incorrect file ASN.1-data tag – the actual value is not as expected.
    */
    DG_WRONG_TAG = 2147483760,
    /**
    * Incorrect format of the file ASN.1-data.
    */
    DG_CONTENTS_UNEXPECTED_DATA = 2147483761,
    /**
    * Can't create specified cypher object for BAP procedure.
    */
    BAP_SYMMETRIC_CYPHER_CANT_INITIALIZE = 2164260881,
    /**
    * PACE parameters are not defined at the time of the procedure – the corresponding PACEInfo is not found
    */
    PACE_INFO_NOT_AVAILABLE = 2164260896,
    /**
    * Error of symmetric cipher object creating for PACE
    */
    PACE_SYMMETRIC_CYPHER_CANT_INITIALIZE = 2164260897,
    /**
    * Error of key agreement object creating for PACE
    */
    PACE_KEY_AGREEMENT_CANT_INITIALIZE = 2164260898,
    /**
    * Error of creating a pair of ephemeral keys for PACE
    */
    PACE_EPHEMERAL_KEYS_CANT_CREATE = 2164260899,
    /**
    * Error of nonce decoding, received from the chip, for use in the mapping operation
    */
    PACE_MAPPING_CANT_DECODE_NONCE = 2164260900,
    /**
    * Error of computing shared secret for PACE procedure.
    */
    PACE_SHARED_SECRET_CANT_CREATE = 2164260901,
    /**
    * The parameters of ECDH public key it is allowed to use only
    * prime-curves with unpacked points.
    */
    PACE_DOMAIN_PARAMS_UNSUPPORTED_FORMAT = 2164260902,
    /**
    * PACE ephemeral public keys (terminal and chip) differ in the length or the same
    */
    PACE_EPHEMERAL_KEYS_INCORRECT = 2164260903,
    /**
    * PACE ephemeral public keys (terminal and chip) for use in the mapping operation differ in the length.
    */
    PACE_MAPPING_EPHEMERAL_KEYS_INCORRECT = 2164260904,
    /**
    * Error of PACE mapping operation – failed to compute the new key pair
    */
    PACE_MAPPING_CANT_PERFORM = 2164260905,
    /**
    * PACE authentication tokens of terminal and chip are different
    */
    PACE_NON_MATCHING_AUTH_TOKENS = 2164260906,
    /**
    * Incorrect PACE-CAM data received from the chip
    */
    PACE_CAM_DATA_INCORRECT = 2164260907,
    /**
    * PACE-CAM data verification failed
    */
    PACE_CAM_DATA_CANT_VERIFY = 2164260908,
    /**
    * PACE-CAM data verification failed (length, contents).
    */
    PACE_CAM_DATA_NON_MATCHING = 2164260909,
    /**
    * Incorrect Integrated Mapping scheme (allowed Elliptic Curves only)
    */
    PACE_IM_SCHEME_INCORRECT = 2164260910,
    /**
    * Can't perform Pseudo Random Mapping
    */
    PACE_IM_RANDOM_MAPPING_FAILED = 2164260911,
    /**
    * CA public key parameters are not defined at the time of the procedure – the corresponding
    * ChipAuthenticationPublicKeyInfo is not found
    */
    CA_CANT_FIND_PUBLIC_KEY = 2164260912,
    /**
    * CA parameters (for version 2) are not defined at the time of the procedure –
    * the corresponding ChipAuthenticationInfo is not found
    */
    CA_CANT_FIND_INFO = 2164260913,
    /**
    * Unsupported CA version in ChipAuthenticationInfo field of the ASN.1-object. The
    * values 1 or 2 are allowed&.
    */
    CA_INCORRECT_VERSION = 2164260914,
    /**
    * Impossible to define the CA public key parameters at the time of the procedure.
    */
    CA_CANT_FIND_DOMAIN_PARAMETERS = 2164260915,
    /**
    * Error of key object agreement creation for CA
    */
    CA_KEY_AGREEMENT_CANT_INITIALIZE = 2164260916,
    /**
    * Unsupported CA public key algorithm
    */
    CA_PUBLIC_KEY_UNSUPPORTED_ALGORITHM = 2164260917,
    /**
    * Error of creating a pair of ephemeral keys for CA
    */
    CA_EPHEMERAL_KEYS_CANT_CREATE = 2164260918,
    /**
    * Error of computing shared secret for CA
    */
    CA_SHARED_SECRET_CANT_CREATE = 2164260919,
    /**
    * CA authentication tokens of terminal and chip are different
    */
    CA_NON_MATCHING_AUTH_TOKENS = 2164260920,
    /**
    * Unsupported TA version in TerminalAuthenticationInfo field of the ASN.1-object.
    * The values 1 or 2 are allowed
    */
    TA_INCORRECT_VERSION = 2164260928,
    /**
    * Error of building a certificate chain. DV- and terminal certificate must be present at least.
    */
    TA_CANT_BUILD_CERTIFICATE_CHAIN = 2164260929,
    /**
    * Data of private key corresponding to the terminal certificate not found.
    */
    TA_CANT_FIND_IS_PRIVATE_KEY = 2164260930,
    /**
    * Unsupported TA public key algorithm
    */
    TA_PUBLIC_KEY_UNSUPPORTED_ALGORITHM = 2164260931,
    /**
    * Error of TA digital signature calculation
    */
    TA_SIGNATURE_BUILDING_ERROR = 2164260932,
    /**
    * Incorrect TA public key parameters
    */
    TA_INVALID_KEY_ALGORITHM_PARAMETERS = 2164260933,
    /**
    * Unsupported AA public key algorithm
    */
    AA_PUBLIC_KEY_UNSUPPORTED_ALGORITHM = 2164260944,
    /**
    * Incorrect format of AA public key data
    */
    AA_PUBLIC_KEY_INCORRECT_DATA = 2164260945,
    /**
    * Incorrect format of AA public key parameters data
    */
    AA_PUBLIC_KEY_INCORRECT_PARAMETERS = 2164260946,
    /**
    * ECDSA public key parameters are not defined. According to they are defined by
    * EcpkParameters ASN.1-object by one of three possible ways: explicitly, by the named
    * curve identifier, can also be known a priori. In the case when the parameters are assigned
    * implicity or the specified identifier of the curve is not supported, a procedure of AA becomes impossible.
    */
    AA_PUBLIC_KEY_UNDEFINED_PARAMETERS = 2164260947,
    /**
    * Incorrect data of AA digital signature (by length or compliance with a range of valid values).
    */
    AA_SIGNATURE_INCORRECT_DATA = 2164260948,
    /**
    * Unsupported message recovery scheme. According to only algorithm of partial recovery is supported.
    */
    AA_UNSUPPORTED_RECOVERY_SCHEME = 2164260949,
    /**
    * Unsupported trailer of recovered data – only ‘BC’ and ‘CC’ values are supported
    */
    AA_INCORRECT_TRAILER = 2164260950,
    /**
    * Unsupported data hash algorithm
    */
    AA_UNSUPPORTED_DIGEST_ALGORITHM = 2164260951,
    /**
    * It is impossible to find the sector public key data for RI
    */
    RI_SECTOR_KEY_CANT_FIND = 2164260976,
    /**
    * Incorrect sector public key data
    */
    RI_SECTOR_KEY_INCORRECT_DATA = 2164260977,
    /**
    * All RI sector public key key parameters must be defined explicitly
    */
    RI_SECTOR_KEY_INCOMPLETE_DATA = 2164260978,
    /**
    * Absence of mandatory data fields in the structure of CV-certificate public key object
    */
    CV_CERTIFICATE_MISSING_MANDATORY_DATA_PK = 2164260960,
    /**
    * Unsupported public key format in the CV-certificate (for TA) (See also description of
    * CA_PUBLIC_KEY_UNSUPPORTED_ALGORITHM)
    */
    CV_CERTIFICATE_PUBLIC_KEY_UNSUPPORTED = 2164260962,
    /**
    * Unsupported type of terminal in the CV-certificate
    */
    CV_CERTIFICATE_CHAT_UNSUPPORTED_TERMINAL_TYPE = 2164260963,
    /**
    * Unsupported key algorithm in the terminal private key data
    */
    CV_CERTIFICATE_PRIVATE_KEY_UNSUPPORTED = 2164260964,
    /**
    * Incorrect terminal private key parameters data
    */
    CV_CERTIFICATE_PRIVATE_KEY_INVALID_PARAMS = 2164260965,
    /**
    * Incorrect format of CV-certificate TLV-data
    */
    CV_CERTIFICATE_INCORRECT_DATA = 2164261216,
    /**
    * Incorrect format of the CV-certificate "Certificate Profile Identifier" field
    */
    CV_CERTIFICATE_CPI_INCORRECT_DATA = 2164261217,
    /**
    * Incorrect format of the CV-certificate "Certificate Authority Reference" field
    */
    CV_CERTIFICATE_CAR_INCORRECT_DATA = 2164261218,
    /**
    * Incorrect format of the CV-certificate public key data
    */
    CV_CERTIFICATE_PUBLIC_KEY_INCORRECT_DATA = 2164261219,
    /**
    * Incorrect format of the CV-certificate "Certificate Holder Reference" field
    */
    CV_CERTIFICATE_CHR_INCORRECT_DATA = 2164261220,
    /**
    * Incorrect format of the CV-certificate "Certificate Holder Authorization Template" field.
    */
    CV_CERTIFICATE_CHAT_INCORRECT_DATA = 2164261221,
    /**
    * Invalid format of "Certificate Effective Date" field in CV-certificate
    */
    CV_CERTIFICATE_VALID_FROM_INCORRECT_DATA = 2164261222,
    /**
    * Incorrect format of the CV-certificate "Certificate Effective Date" field
    */
    CV_CERTIFICATE_VALID_TO_INCORRECT_DATA = 2164261223,
    /**
    * Incorrect format of the CV-certificate extensions
    */
    CV_CERTIFICATE_EXTENSIONS_INCORRECT_DATA = 2164261224,
    /**
    * Incorrect format of the private key data
    */
    CV_CERTIFICATE_PRIVATE_KEY_INCORRECT_DATA = 2164261225,
    /**
    * Corresponding private key is not found for the terminal certificate
    */
    CV_CERTIFICATE_PRIVATE_KEY_MISSING = 2164261226
}
